@@ -1,5 +1,5 @@
 package List::Compare::Base::_Auxiliary;
-$VERSION = 0.49;
+$VERSION = 0.50;
 use Carp;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw|
@@ -258,24 +258,43 @@ sub _calculate_sharedref {
     }
     return $sharedref;
 }
-
+sub _is_list_subset {
+	my ( $subset, $superset ) = @_;
+	# return false if the superset value is false
+	# for any subset value.
+	# note that this does *not* validate overlap of
+	# the keys; it validates the truth of supserset
+	# values.
+	$superset->{ $_ } or return 0 for keys %$subset;
+    return 1;
+}
 sub _subset_subengine {
     my $aref = shift;
     my (@xsubset);
     my %seen = %{_calculate_seen_only($aref)};
     foreach my $i (keys %seen) {
-        my %tempi = %{$seen{$i}};
         foreach my $j (keys %seen) {
-            my %tempj = %{$seen{$j}};
-            $xsubset[$i][$j] = 1;
-            foreach my $k (keys %tempi) {
-                $xsubset[$i][$j] = 0 if (! $tempj{$k});
+            if ( $i eq $j ) {
+                $xsubset[$i][$j] = 1;
+            }
+            elsif ( $i gt $j ) {
+                if ( scalar(keys %{ $seen{$i} }) == scalar(keys %{ $seen{$j} }) ){
+                    $xsubset[$i][$j] = _is_list_subset($seen{$i}, $seen{$j});
+                    $xsubset[$j][$i] = $xsubset[$i][$j];
+                }
+                elsif ( scalar(keys %{ $seen{$i} }) < scalar(keys %{ $seen{$j} }) ){
+                    $xsubset[$i][$j] = _is_list_subset($seen{$i}, $seen{$j});
+                    $xsubset[$j][$i] = 0;
+                }
+                elsif ( scalar(keys %{ $seen{$i} }) > scalar(keys %{ $seen{$j} }) ){
+                    $xsubset[$j][$i] = _is_list_subset($seen{$i}, $seen{$j});
+                    $xsubset[$i][$j] = 0;
+                }
             }
         }
     }
     return \@xsubset;
 }
-
 sub _chart_engine_regular {
     my $aref = shift;
     my @sub_or_eqv = @$aref;
@@ -696,8 +715,8 @@ List::Compare::Base::_Auxiliary - Internal use only
 
 =head1 VERSION
 
-This document refers to version 0.49 of List::Compare::Base::_Auxiliary.
-This version was released February 25 2015.
+This document refers to version 0.50 of List::Compare::Base::_Auxiliary.
+This version was released May 09 2015.
 
 =head1 SYNOPSIS
 
@@ -709,7 +728,7 @@ List::Compare::Functional.  They are not intended to be publicly callable.
 James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'List::Compare' or 'List-Compare' in your subject line.
 
-Creation date:  May 20, 2002.  Last modification date:  February 25 2015.
+Creation date:  May 20, 2002.  Last modification date:  May 09 2015.
 Copyright (c) 2002-15 James E. Keenan.  United States.  All rights reserved.
 This is free software and may be distributed under the same terms as Perl
 itself.
